@@ -1,5 +1,5 @@
 /* This file is part of KCachegrind.
-   Copyright (c) 2002-2015 Josef Weidendorfer <Josef.Weidendorfer@gmx.de>
+   Copyright (c) 2002-2016 Josef Weidendorfer <Josef.Weidendorfer@gmx.de>
 
    KCachegrind is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public
@@ -22,6 +22,8 @@
 
 #include "tracedata.h"
 
+#include <QObject>
+
 #define TRACE_DEBUG      0
 #define TRACE_ASSERTIONS 0
 
@@ -30,11 +32,11 @@
 
 CostItem::CostItem(ProfileContext* c)
 {
-  _position = 0;
-  _dep = 0;
-  _dirty = true;
+    _position = 0;
+    _dep = 0;
+    _dirty = true;
 
-  _context = c;
+    _context = c;
 }
 
 CostItem::~CostItem()
@@ -49,19 +51,19 @@ void CostItem::clear()
 
 QString CostItem::costString(EventTypeSet*)
 {
-    return QString("(no cost)");
+    return QStringLiteral("(no cost)");
 }
 
 QString CostItem::name() const
 {
-  if (part()) {
-      return QObject::tr("%1 from %2").arg(_dep->name()).arg(part()->name());
-  }
+    if (part()) {
+        return QObject::tr("%1 from %2").arg(_dep->name()).arg(part()->name());
+    }
 
-  if (_dep)
-    return _dep->name();
+    if (_dep)
+        return _dep->name();
 
-  return QObject::tr("(unknown)");
+    return QObject::tr("(unknown)");
 }
 
 QString CostItem::prettyName() const
@@ -77,47 +79,47 @@ QString CostItem::formattedName() const
 
 QString CostItem::fullName() const
 {
-  return QString("%1 %2")
-    .arg(ProfileContext::typeName(type())).arg(prettyName());
+    return QStringLiteral("%1 %2")
+            .arg(ProfileContext::typeName(type())).arg(prettyName());
 }
 
 QString CostItem::toString()
 {
-  return QString("%1\n  [%3]").arg(fullName()).arg(costString(0));
+    return QStringLiteral("%1\n  [%3]").arg(fullName()).arg(costString(0));
 }
 
 void CostItem::invalidate()
 {
-  if (_dirty) return;
-  _dirty = true;
+    if (_dirty) return;
+    _dirty = true;
 
-  if (_dep)
-    _dep->invalidate();
+    if (_dep)
+        _dep->invalidate();
 }
 
 void CostItem::update()
 {
-  _dirty = false;
+    _dirty = false;
 }
 
 TracePart* CostItem::part()
 {
-  return _position ? _position->part() : 0;
+    return _position ? _position->part() : 0;
 }
 
 const TracePart* CostItem::part() const
 {
-  return _position ? _position->part() : 0;
+    return _position ? _position->part() : 0;
 }
 
 TraceData* CostItem::data()
 {
-  return _position ? _position->data() : 0;
+    return _position ? _position->data() : 0;
 }
 
 const TraceData* CostItem::data() const
 {
-  return _position ? _position->data() : 0;
+    return _position ? _position->data() : 0;
 }
 
 
@@ -132,19 +134,19 @@ const int ProfileCostArray::InvalidIndex = -1;
 ProfileCostArray::ProfileCostArray(ProfileContext* context)
     : CostItem(context)
 {
-  _cachedType = 0; // no virtual value cached
-  _allocCount = 0;
-  _count = 0;
-  _cost = 0;
+    _cachedType = 0; // no virtual value cached
+    _allocCount = 0;
+    _count = 0;
+    _cost = 0;
 }
 
 ProfileCostArray::ProfileCostArray()
     : CostItem(ProfileContext::context(ProfileContext::UnknownType))
 {
-  _cachedType = 0; // no virtual value cached
-  _allocCount = 0;
-  _count = 0;
-  _cost = 0;
+    _cachedType = 0; // no virtual value cached
+    _allocCount = 0;
+    _count = 0;
+    _cost = 0;
 }
 
 ProfileCostArray::~ProfileCostArray()
@@ -179,7 +181,7 @@ void ProfileCostArray::set(EventTypeMapping* mapping, const char* s)
     if (!mapping) return;
     if (!s) {
         clear();
-	return;
+        return;
     }
 
     reserve(mapping->set()->realCount());
@@ -187,26 +189,26 @@ void ProfileCostArray::set(EventTypeMapping* mapping, const char* s)
     while(*s == ' ') s++;
 
     if (mapping->isIdentity()) {
-	int i = 0;
-	while(i<mapping->count()) {
-	    if (!_cost[i].set(&s)) break;
-	    i++;
-	}
-	_count = i;
+        int i = 0;
+        while(i<mapping->count()) {
+            if (!_cost[i].set(&s)) break;
+            i++;
+        }
+        _count = i;
     }
     else {
-	int i = 0, maxIndex = 0, index;
-	while(1) {
-	    index = mapping->realIndex(i);
-	    if (maxIndex<index) maxIndex=index;
-	    if (index == ProfileCostArray::InvalidIndex) break;
-	    if (!_cost[index].set(&s)) break;
-	    i++;
-	}
-	// we have to set all costs of unused indexes till maxIndex to zero
-	for(i=mapping->firstUnused(); i<=maxIndex; i=mapping->nextUnused(i))
-	    _cost[i] = 0;
-	_count = maxIndex;
+        int i = 0, maxIndex = 0, index;
+        while(1) {
+            index = mapping->realIndex(i);
+            if (maxIndex<index) maxIndex=index;
+            if (index == ProfileCostArray::InvalidIndex) break;
+            if (!_cost[index].set(&s)) break;
+            i++;
+        }
+        // we have to set all costs of unused indexes till maxIndex to zero
+        for(i=mapping->firstUnused(); i<=maxIndex; i=mapping->nextUnused(i))
+            _cost[i] = 0;
+        _count = maxIndex;
     }
     Q_ASSERT(_count <= _allocCount);
     // a cost change has to be propagated (esp. in subclasses)
@@ -225,26 +227,26 @@ void ProfileCostArray::set(EventTypeMapping* mapping, FixString & s)
     reserve(mapping->set()->realCount());
 
     if (mapping->isIdentity()) {
-	int i = 0;
-	while(i<mapping->count()) {
-	    if (!s.stripUInt64(_cost[i])) break;
-	    i++;
-	}
-	_count = i;
+        int i = 0;
+        while(i<mapping->count()) {
+            if (!s.stripUInt64(_cost[i])) break;
+            i++;
+        }
+        _count = i;
     }
     else {
-	int i = 0, maxIndex = 0, index;
-	while(1) {
-	    index = mapping->realIndex(i);
-	    if (maxIndex<index) maxIndex=index;
-	    if (index == ProfileCostArray::InvalidIndex) break;
-	    if (!s.stripUInt64(_cost[index])) break;
-	    i++;
-	}
-	// we have to set all costs of unused indexes till maxIndex to zero
-	for(i=mapping->firstUnused(); i<=maxIndex; i=mapping->nextUnused(i))
-	    _cost[i] = 0;
-	_count = maxIndex+1;
+        int i = 0, maxIndex = 0, index;
+        while(1) {
+            index = mapping->realIndex(i);
+            if (maxIndex<index) maxIndex=index;
+            if (index == ProfileCostArray::InvalidIndex) break;
+            if (!s.stripUInt64(_cost[index])) break;
+            i++;
+        }
+        // we have to set all costs of unused indexes till maxIndex to zero
+        for(i=mapping->firstUnused(); i<=maxIndex; i=mapping->nextUnused(i))
+            _cost[i] = 0;
+        _count = maxIndex+1;
     }
     Q_ASSERT(_count <= _allocCount);
     invalidate();
@@ -258,37 +260,37 @@ void ProfileCostArray::addCost(EventTypeMapping* mapping, const char* s)
 
     SubCost v;
     if (mapping->isIdentity()) {
-	int i = 0;
-	while(i<mapping->count()) {
-	    if (!v.set(&s)) break;
-	    if (i<_count)
-		_cost[i] += v;
-	    else
-		_cost[i] = v;
-	    i++;
-	}
-	if (i > _count) _count = i;
+        int i = 0;
+        while(i<mapping->count()) {
+            if (!v.set(&s)) break;
+            if (i<_count)
+                _cost[i] += v;
+            else
+                _cost[i] = v;
+            i++;
+        }
+        if (i > _count) _count = i;
     }
     else {
-	int i = 0, maxIndex = 0, index;
-	while(1) {
-	    if (!v.set(&s)) break;
-	    index = mapping->realIndex(i);
-	    if (maxIndex<index) maxIndex=index;
-	    if (index == ProfileCostArray::InvalidIndex) break;
-	    if (index<_count)
-		_cost[index] += v;
-	    else
-		_cost[index] = v;
-	    i++;
-	}
-	if (maxIndex >= _count) {
-	    /* we have to set all costs of unused indexes in the interval
-	     *  [_count;maxIndex] to zero */
-	    for(i=mapping->nextUnused(_count-1); i<=maxIndex; i=mapping->nextUnused(i))
-		_cost[i] = 0;
-	    _count = maxIndex+1;
-	}
+        int i = 0, maxIndex = 0, index;
+        while(1) {
+            if (!v.set(&s)) break;
+            index = mapping->realIndex(i);
+            if (maxIndex<index) maxIndex=index;
+            if (index == ProfileCostArray::InvalidIndex) break;
+            if (index<_count)
+                _cost[index] += v;
+            else
+                _cost[index] = v;
+            i++;
+        }
+        if (maxIndex >= _count) {
+            /* we have to set all costs of unused indexes in the interval
+             *  [_count;maxIndex] to zero */
+            for(i=mapping->nextUnused(_count-1); i<=maxIndex; i=mapping->nextUnused(i))
+                _cost[i] = 0;
+            _count = maxIndex+1;
+        }
     }
 
     Q_ASSERT(_count <= _allocCount);
@@ -297,7 +299,7 @@ void ProfileCostArray::addCost(EventTypeMapping* mapping, const char* s)
 #if TRACE_DEBUG
     _dirty = false; // do not recurse !
     qDebug("%s\n now %s", qPrintable( fullName() ),
-	   qPrintable( ProfileCostArray::costString(0) ));
+           qPrintable( ProfileCostArray::costString(0) ));
     _dirty = true; // because of invalidate()
 #endif
 }
@@ -311,37 +313,37 @@ void ProfileCostArray::addCost(EventTypeMapping* mapping, FixString & s)
 
     SubCost v;
     if (mapping->isIdentity()) {
-	int i = 0;
-	while(i<mapping->count()) {
-	    if (!s.stripUInt64(v)) break;
-	    if (i<_count)
-		_cost[i] += v;
-	    else
-		_cost[i] = v;
-	    i++;
-	}
-	if (i > _count) _count = i;
+        int i = 0;
+        while(i<mapping->count()) {
+            if (!s.stripUInt64(v)) break;
+            if (i<_count)
+                _cost[i] += v;
+            else
+                _cost[i] = v;
+            i++;
+        }
+        if (i > _count) _count = i;
     }
     else {
-	int i = 0, maxIndex = 0, index;
-	while(1) {
-	    if (!s.stripUInt64(v)) break;
-	    index = mapping->realIndex(i);
-	    if (maxIndex<index) maxIndex=index;
-	    if (index == ProfileCostArray::InvalidIndex) break;
-	    if (index<_count)
-		_cost[index] += v;
-	    else
-		_cost[index] = v;
-	    i++;
-	}
-	if (maxIndex >= _count) {
-	    /* we have to set all costs of unused indexes in the interval
-	     *  [_count;maxIndex] to zero */
-	    for(i=mapping->nextUnused(_count-1); i<=maxIndex; i=mapping->nextUnused(i))
-		_cost[i] = 0;
-	    _count = maxIndex+1;
-	}
+        int i = 0, maxIndex = 0, index;
+        while(1) {
+            if (!s.stripUInt64(v)) break;
+            index = mapping->realIndex(i);
+            if (maxIndex<index) maxIndex=index;
+            if (index == ProfileCostArray::InvalidIndex) break;
+            if (index<_count)
+                _cost[index] += v;
+            else
+                _cost[index] = v;
+            i++;
+        }
+        if (maxIndex >= _count) {
+            /* we have to set all costs of unused indexes in the interval
+             *  [_count;maxIndex] to zero */
+            for(i=mapping->nextUnused(_count-1); i<=maxIndex; i=mapping->nextUnused(i))
+                _cost[i] = 0;
+            _count = maxIndex+1;
+        }
     }
 
     Q_ASSERT(_count <= _allocCount);
@@ -350,7 +352,7 @@ void ProfileCostArray::addCost(EventTypeMapping* mapping, FixString & s)
 #if TRACE_DEBUG
     _dirty = false; // do not recurse !
     qDebug("%s\n now %s", qPrintable( fullName() ),
-	   qPrintable( ProfileCostArray::costString(0 ) ) );
+           qPrintable( ProfileCostArray::costString(0 ) ) );
     _dirty = true; // because of invalidate()
 #endif
 }
@@ -366,39 +368,39 @@ void ProfileCostArray::maxCost(EventTypeMapping* mapping, FixString & s)
 
     SubCost v;
     if (mapping->isIdentity()) {
-	int i = 0;
-	while(i<mapping->count()) {
-	    if (!s.stripUInt64(v)) break;
-	    if (i<_count) {
-	      if (v>_cost[i]) _cost[i] = v;
-	    }
-	    else
-		_cost[i] = v;
-	    i++;
-	}
-	if (i > _count) _count = i;
+        int i = 0;
+        while(i<mapping->count()) {
+            if (!s.stripUInt64(v)) break;
+            if (i<_count) {
+                if (v>_cost[i]) _cost[i] = v;
+            }
+            else
+                _cost[i] = v;
+            i++;
+        }
+        if (i > _count) _count = i;
     }
     else {
-	int i = 0, maxIndex = 0, index;
-	while(1) {
-	    if (!s.stripUInt64(v)) break;
-	    index = mapping->realIndex(i);
-	    if (maxIndex<index) maxIndex=index;
-	    if (index == ProfileCostArray::InvalidIndex) break;
-	    if (index<_count) {
-	      if (v>_cost[index]) _cost[index] = v;
-	    }
-	    else
-		_cost[index] = v;
-	    i++;
-	}
-	if (maxIndex >= _count) {
-	    /* we have to set all costs of unused indexes in the interval
-	     *  [_count;maxIndex] to zero */
-	    for(i=mapping->nextUnused(_count-1); i<=maxIndex; i=mapping->nextUnused(i))
-		_cost[i] = 0;
-	    _count = maxIndex+1;
-	}
+        int i = 0, maxIndex = 0, index;
+        while(1) {
+            if (!s.stripUInt64(v)) break;
+            index = mapping->realIndex(i);
+            if (maxIndex<index) maxIndex=index;
+            if (index == ProfileCostArray::InvalidIndex) break;
+            if (index<_count) {
+                if (v>_cost[index]) _cost[index] = v;
+            }
+            else
+                _cost[index] = v;
+            i++;
+        }
+        if (maxIndex >= _count) {
+            /* we have to set all costs of unused indexes in the interval
+             *  [_count;maxIndex] to zero */
+            for(i=mapping->nextUnused(_count-1); i<=maxIndex; i=mapping->nextUnused(i))
+                _cost[i] = 0;
+            _count = maxIndex+1;
+        }
     }
 
     Q_ASSERT(_count <= _allocCount);
@@ -407,7 +409,7 @@ void ProfileCostArray::maxCost(EventTypeMapping* mapping, FixString & s)
 #if TRACE_DEBUG
     _dirty = false; // do not recurse !
     qDebug("%s\n now %s", qPrintable( fullName() ),
-	   qPrintable(ProfileCostArray::costString(0)));
+           qPrintable(ProfileCostArray::costString(0)));
     _dirty = true; // because of invalidate()
 #endif
 }
@@ -427,14 +429,14 @@ void ProfileCostArray::addCost(ProfileCostArray* item)
 
     if (item->_count < _count) {
         for (i = 0; i<item->_count; ++i)
-	    _cost[i] += item->_cost[i];
+            _cost[i] += item->_cost[i];
     }
     else {
         for (i = 0; i<_count; ++i)
-	    _cost[i] += item->_cost[i];
+            _cost[i] += item->_cost[i];
         for (; i<item->_count; ++i)
-	    _cost[i] = item->_cost[i];
-	_count = item->_count;
+            _cost[i] = item->_cost[i];
+        _count = item->_count;
     }
 
     Q_ASSERT(_count <= _allocCount);
@@ -443,8 +445,8 @@ void ProfileCostArray::addCost(ProfileCostArray* item)
 #if TRACE_DEBUG
     _dirty = false; // do not recurse !
     qDebug("%s added cost item\n %s\n  now %s",
-	   qPrintable( fullName() ), qPrintable(item->fullName()),
-	   qPrintable(ProfileCostArray::costString(0)));
+           qPrintable( fullName() ), qPrintable(item->fullName()),
+           qPrintable(ProfileCostArray::costString(0)));
     _dirty = true; // because of invalidate()
 #endif
 }
@@ -464,14 +466,14 @@ void ProfileCostArray::maxCost(ProfileCostArray* item)
 
     if (item->_count < _count) {
         for (i = 0; i<item->_count; ++i)
-	  if (_cost[i] < item->_cost[i]) _cost[i] = item->_cost[i];
+            if (_cost[i] < item->_cost[i]) _cost[i] = item->_cost[i];
     }
     else {
         for (i = 0; i<_count; ++i)
-	  if (_cost[i] < item->_cost[i]) _cost[i] = item->_cost[i];
+            if (_cost[i] < item->_cost[i]) _cost[i] = item->_cost[i];
         for (; i<item->_count; ++i)
-	    _cost[i] = item->_cost[i];
-	_count = item->_count;
+            _cost[i] = item->_cost[i];
+        _count = item->_count;
     }
 
     Q_ASSERT(_count <= _allocCount);
@@ -480,8 +482,8 @@ void ProfileCostArray::maxCost(ProfileCostArray* item)
 #if TRACE_DEBUG
     _dirty = false; // do not recurse !
     qDebug("%s added cost item\n %s\n  now %s",
-	   qPrintable( fullName() ), qPrintable(item->fullName()),
-	   qPrintable( ProfileCostArray::costString(0) ));
+           qPrintable( fullName() ), qPrintable(item->fullName()),
+           qPrintable( ProfileCostArray::costString(0) ));
     _dirty = true; // because of invalidate()
 #endif
 }
@@ -496,9 +498,9 @@ void ProfileCostArray::addCost(int realIndex, SubCost value)
         _cost[realIndex] += value;
     else {
         for(int i=_count;i<realIndex;i++)
-	    _cost[i] = 0;
-	_cost[realIndex] = value;
-	_count = realIndex+1;
+            _cost[i] = 0;
+        _cost[realIndex] = value;
+        _count = realIndex+1;
     }
 
     Q_ASSERT(_count <= _allocCount);
@@ -511,13 +513,13 @@ void ProfileCostArray::maxCost(int realIndex, SubCost value)
 
     reserve(realIndex+1);
     if (realIndex<_count) {
-      if (value>_cost[realIndex]) _cost[realIndex] = value;
+        if (value>_cost[realIndex]) _cost[realIndex] = value;
     }
     else {
         for(int i=_count;i<realIndex;i++)
-	    _cost[i] = 0;
-	_cost[realIndex] = value;
-	_count = realIndex+1;
+            _cost[i] = 0;
+        _cost[realIndex] = value;
+        _count = realIndex+1;
     }
 
     Q_ASSERT(_count <= _allocCount);
@@ -529,51 +531,51 @@ ProfileCostArray ProfileCostArray::diff(ProfileCostArray* item)
 {
     ProfileCostArray res(context());
 
-  // we have to update the other item if needed
-  // because we access the item costs directly
-  if (item->_dirty) item->update();
+    // we have to update the other item if needed
+    // because we access the item costs directly
+    if (item->_dirty) item->update();
 
-  int maxCount = (item->_count > _count) ? item->_count : _count;
+    int maxCount = (item->_count > _count) ? item->_count : _count;
 
-  res.reserve(maxCount);
-  for (int i=0; i<maxCount;i++)
-    res._cost[i] = item->subCost(i) - subCost(i);
-  res._count = maxCount;
+    res.reserve(maxCount);
+    for (int i=0; i<maxCount;i++)
+        res._cost[i] = item->subCost(i) - subCost(i);
+    res._count = maxCount;
 
-  Q_ASSERT(res._count <= res._allocCount);
-  return res;
+    Q_ASSERT(res._count <= res._allocCount);
+    return res;
 }
 
 QString ProfileCostArray::costString(EventTypeSet* set)
 {
-  QString res;
+    QString res;
 
-  if (_dirty) update();
+    if (_dirty) update();
 
-  int maxIndex = set ? set->realCount() : ProfileCostArray::MaxRealIndex;
-  for (int i = 0; i<maxIndex; i++) {
-    if (!res.isEmpty()) res += ", ";
-    if (set) res += set->type(i)->name() + ' ';
+    int maxIndex = set ? set->realCount() : ProfileCostArray::MaxRealIndex;
+    for (int i = 0; i<maxIndex; i++) {
+        if (!res.isEmpty()) res += QLatin1String(", ");
+        if (set) res += set->type(i)->name() + ' ';
 
-    res += subCost(i).pretty();
-  }
-  return res;
+        res += subCost(i).pretty();
+    }
+    return res;
 }
 
 
 void ProfileCostArray::invalidate()
 {
-  if (_dirty) return;
-  _dirty = true;
-  _cachedType = 0; // cached value is invalid, too
+    if (_dirty) return;
+    _dirty = true;
+    _cachedType = 0; // cached value is invalid, too
 
-  if (_dep)
-    _dep->invalidate();
+    if (_dep)
+        _dep->invalidate();
 }
 
 void ProfileCostArray::update()
 {
-  _dirty = false;
+    _dirty = false;
 }
 
 // this is only for real types
@@ -592,12 +594,12 @@ SubCost ProfileCostArray::subCost(int idx)
 
 SubCost ProfileCostArray::subCost(EventType* t)
 {
-  if (!t) return 0;
-  if (_cachedType != t) {
-      _cachedType = t;
-      _cachedCost = t->subCost(this);
-  }
-  return _cachedCost;
+    if (!t) return 0;
+    if (_cachedType != t) {
+        _cachedType = t;
+        _cachedCost = t->subCost(this);
+    }
+    return _cachedCost;
 }
 
 QString ProfileCostArray::prettySubCost(EventType* t)
